@@ -692,13 +692,17 @@ class MDSimulation():
         del self.simulation
         self._build_sim()
 
-    def _add_reporters(self, total_steps=1):
+    def _add_reporters(self, total_steps=1, traj_interval=None):
         """ Add reporters to the sim object
 
         total_steps int
             total_steps is needed for accurate estimate of time remaining in progress reporter.
 
         """
+
+        if traj_interval is None:
+            traj_interval = self.traj_interval
+
         if self.progress_interval:
             if isinstance(self.progress_interval, unit.Quantity):
                 prog_int = self.progress_interval / self.step_length
@@ -763,11 +767,11 @@ class MDSimulation():
 
             self.simulation.reporters.append(state_reporter)
 
-        if self.traj_interval:
-            if isinstance(self.traj_interval, unit.Quantity):
-                traj_int = self.traj_interval / self.step_length
+        if traj_interval:
+            if isinstance(traj_interval, unit.Quantity):
+                traj_int = traj_interval / self.step_length
             else:
-                raise ValueError('traj report interval must have units, got {}'.format(self.traj_interval))
+                raise ValueError('traj report interval must have units, got {}'.format(traj_interval))
 
             traj_file = os.path.join(self.cwd, self.traj_out)
             traj_steps = int(round(traj_int))
@@ -1231,13 +1235,17 @@ class MetadynamicSimulation(MDSimulation):
         self.simulation.context.setPositions(self.positions)
 
 
-    def _add_FESReporter(self):
+    def _add_FESReporter(self,fes_interval=None):
         """
         adds the FES reporter to the sim
         :return:
         """
 
-        fes_steps = int(round(self.fes_interval))
+
+        if fes_interval is None:
+            fes_steps = round(self.fes_interval)
+        else:
+            fes_steps = int(round(fes_interval / self.step_length))
 
         if fes_steps == 0:
             raise ValueError('FES interval cannot be zero')
