@@ -47,6 +47,7 @@ class SegmentMappingSim(MetadynamicSimulation):
 
         super().__init__(**kwargs)
 
+
         #setup init vars
         self.num_segs = num_segs_per_replica
         self.seg_sim_time = seg_sim_time
@@ -83,22 +84,26 @@ class SegmentMappingSim(MetadynamicSimulation):
         #segment_coords is a list of chosen coordinates from each replica
         segment_coords = []
 
+        self._build_sim()
+        self._build_custom_forces()
+
+        print('saving coords')
+        initial_coords = self.positions
+
+        scan_times = []
         for i in range(self.num_replicas):
 
             print('Starting scan run for replica {}'.format(i+1))
 
-            self._build_sim()
-            self._build_custom_forces()
+            self.simulation.context.reinitialize()
+            self.simulation.context.setPositions(initial_coords)
 
             nsteps = int(self.scan_time / self.step_length)
 
             #fix the reporter intervals to make sure there are enough frames for populating replicas
-            self.traj_interval = .01 * unit.nanosecond
 
-            self.fes_interval = (.01 * unit.nanosecond/self.step_length)
-
-            self._add_reporters(nsteps)
-            self._add_FESReporter()
+            self._add_reporters(total_steps=nsteps * self.num_replicas, traj_interval= .01 * unit.nanosecond)
+            self._add_FESReporter(fes_interval=.01 * unit.nanosecond)
 
             self.metaD.step(self.simulation, nsteps)
             self.update_parmed()
@@ -112,9 +117,10 @@ class SegmentMappingSim(MetadynamicSimulation):
             print('CV distances {}'.format(distances))
 
             scan_clock = self.scan_time
-            while all(distances < np.min(distances)+self.unbound_distance) and  scan_clock<self.max_scan_time:
+            while all(distances < distances[0]+self.unbound_distance) and  scan_clock<self.max_scan_time:
+                print('min(distances',np.min(distances))
                 print('failed to unbind, scanning for another .5 ns')
-                print('CV distances {}'.format(distances))
+                print('CV distance range {} to {}'.format(np.min(distances),np.max(distances)))
                 scan_clock += .5 * unit.nanosecond
                 nsteps = int(.5 * unit.nanosecond / self.step_length)
 
@@ -122,14 +128,16 @@ class SegmentMappingSim(MetadynamicSimulation):
 
                 with open(os.path.join(self.cwd,'CV_values.pickle'), 'rb') as handle:
                     CVs = pickle.load(handle)
-
                 distances = np.array(CVs)[:, 0]
             else:
                 if scan_clock<self.max_scan_time:
+                    scan_times.append(scan_clock)
                     print('ligand reached unbinding distance in {}, proceeding with forced sampling'.format(scan_clock))
                 else:
+                    scan_times.append(scan_clock)
                     print('failed to unbind in max_scan_time, proceeding anyway')
 
+
             print('distances from scan: {}'.format(distances))
 
             self.simulation.reporters.clear()
@@ -160,9 +168,12 @@ class SegmentMappingSim(MetadynamicSimulation):
             bias_file = os.path.join(self.cwd, matches[-1].string)
             os.remove(bias_file)
             self.simulation.reporters.clear()
-            del self.simulation
-            del self.metaD
 
+        with open(os.path.join(self.cwd,'scan_times.pickle'), 'wb') as handle:
+            pickle.dump(scan_times, handle)
+
+        del self.simulation
+        del self.metaD
         seg_steps = int(self.total_production_time / (self.step_length*self.num_segs*self.num_replicas))
 
         self.bias_factor = self.prod_bias
@@ -170,9 +181,8 @@ class SegmentMappingSim(MetadynamicSimulation):
         self._build_sim()
         self._build_custom_forces()
 
-        self.fes_interval = (self.traj_interval / self.step_length)
-
-        self._add_reporters()
+        nsteps = self.total_production_time/self.step_length
+        self._add_reporters(total_steps = nsteps)
         self._add_FESReporter()
 
         #loop across all replicas
